referrerpolicy=no-referrer-when-downgrade

BlockWeightMode

Type Alias BlockWeightMode 

pub type BlockWeightMode<T: Config> = StorageValue<_GeneratedPrefixForStorageBlockWeightMode<T>, BlockWeightMode<T>, OptionQuery>;
The current block weight mode.

This is used to determine what is the maximum allowed block weight, for more information see block_weight.

Killed in [Self::on_initialize] and set by the block_weight logic.

Storage type is [StorageValue] with value type block_weight :: BlockWeightMode < T >.

Aliased Type

pub struct BlockWeightMode<T: Config>(/* private fields */);