referrerpolicy=no-referrer-when-downgrade

LastDmqMqcHead

Type Alias LastDmqMqcHead 

pub type LastDmqMqcHead<T: Config> = StorageValue<_GeneratedPrefixForStorageLastDmqMqcHead<T>, MessageQueueChain, ValueQuery>;
The last downward message queue chain head we have observed.

This value is loaded before and saved after processing inbound downward messages carried by the system inherent.

Storage type is [StorageValue] with value type MessageQueueChain.

Aliased Type

pub struct LastDmqMqcHead<T: Config>(/* private fields */);