pub type PendingApprovedPeer<T: Config> = StorageValue<_GeneratedPrefixForStoragePendingApprovedPeer<T>, ApprovedPeerId, OptionQuery>;Expand description
The approved peer id to be sent as a UMP signal on the last block of the PoV.
Storage type is [StorageValue] with value type relay_chain :: ApprovedPeerId.
Aliased Type
pub struct PendingApprovedPeer<T: Config>(/* private fields */);