pub type LastDmqMqcHead<T: Config> = StorageValue<_GeneratedPrefixForStorageLastDmqMqcHead<T>, MessageQueueChain, ValueQuery>;Expand description
The last downward message queue chain head we have observed.
This value is loaded before and saved after processing inbound downward messages carried by the system inherent.
Storage type is [StorageValue] with value type MessageQueueChain.
Aliased Type
pub struct LastDmqMqcHead<T: Config>(/* private fields */);