pub type PendingValidationCode<T: Config> = StorageValue<_GeneratedPrefixForStoragePendingValidationCode<T>, Vec<u8>, ValueQuery>;Expand description
In case of a scheduled upgrade, this storage field contains the validation code to be applied.
As soon as the relay chain gives us the go-ahead signal, we will overwrite the
[:pending_code][sp_core::storage::well_known_keys::PENDING_CODE] which will result the
next block to be processed with the new validation code. This concludes the upgrade process.
Storage type is [StorageValue] with value type Vec < u8 >.
Aliased Type
pub struct PendingValidationCode<T: Config>(/* private fields */);